# Decentralised Discovery Link

[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link2&metric=alert_status)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link2) [![Bugs](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link2&metric=bugs)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link2) [![Reliability Rating](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link2&metric=reliability_rating)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link2) [![Security Rating](https://sonarcloud.io/api/project_badges/measure?project=Firefox2100_dedi-link2&metric=security_rating)](https://sonarcloud.io/summary/new_code?id=Firefox2100_dedi-link2)

A library to provide core data structures and algorithms for implementations of Decentralised Discovery Link protocol in Python.

This library implements the core data structures and algorithms defined in the [Decentralised Discovery Link specification](https://github.com/Firefox2100/dedi-link-specification). For more details about the protocol, please refer to the specification document.

## Usage

This library is published on PyPI and can be installed via pip:

```bash
pip install dedi-link
```
